@@ -61,10 +61,16 @@ pls <- function(er, ...){
 }
 # setGeneric("pls")
 
+.ER_env$warned_PLS <- FALSE
+
 #' @rdname pls
 #' @method pls ER
 #' @export
 pls.ER <- function(er, effect, ncomp, newdata = NULL, er2, validation, jackknife = NULL, shave = NULL, df.used = NULL, ...){
+  if(!.ER_env$warned_PLS){
+    message(.msg)
+    .ER_env$warned_PLS <- TRUE
+  }
   if(!missing(er2)){
     data <- data.frame(X = I(er$ER.values[[effect]]),
                        y = I(er2$ER.values[[effect]]))
